----------------------------------------------------------
-- Steps:
--     There are several ways to rename the cmx_tran_id column to rhx_tran_id.
--		  2 methods are in this file. Both do not write to the transaction log
-- 			Option 1:
--				Turns Auto Commit off
--				Adds the new column RHX_TRAN_ID
--				Lock the table
--				Activate not logged initially, so the next Update is not logged
--				Update the Table, populating the new column with the value of cmx_tran_id
--				Alter the table to set the new column as NOT NULL
--				Drop the primary key, and 2 indexes that contain the CMX_TRAN_ID Column
--				Alter the table to drop the cmx_tran_id column
--				Reorg the table (keep the compression dictionary, or reset it)
--				Create the new NDX1_RFF index
--				Create the new Primary key index
--				Add the primary key constraint
--				commit;
--
-- 			Option 2: 
--				Turns Auto Commit off
--				Turn integrity off on the table
--				Lock the table
--				Activate not logged initially, so the next Update is not logged
--				Add the new column RHX_TRAN_ID as a generated column, NOT NULL				
--     			populate the new column with the value of cmx_tran_id using the set integrity Force generated command
--				Alter the table to drop the generated column expression
--				Drop the primary key, and 2 indexes that contain the CMX_TRAN_ID Column
--				Alter the table to drop the cmx_tran_id column
--				Reorg the table (keep the compression dictionary, or reset it)
--				Create the new NDX1_RFF index
--				Create the new Primary key index
--				Add the primary key constraint
--				commit;
----------------------------------------------------------
--
-- Alter Table Statements for FRH_RULE_FIRE_FACT 
--
----------------------------------------------------------

----------------------------------------------------------
-- OPTION 1: No logging, Requires Reorg, Update statement to populate column 
----------------------------------------------------------

--UPDATE COMMAND OPTIONS USING c OFF;
--ALTER TABLE FRH_RULE_FIRE_FACT ADD COLUMN RHX_TRAN_ID BIGINT;
--LOCK TABLE FRH_RULE_FIRE_FACT IN EXCLUSIVE MODE;
--ALTER TABLE FRH_RULE_FIRE_FACT ACTIVATE NOT LOGGED INITIALLY;
--UPDATE FRH_RULE_FIRE_FACT SET RHX_TRAN_ID = CMX_TRAN_ID;
--ALTER TABLE FRH_RULE_FIRE_FACT ALTER COLUMN RHX_TRAN_ID  SET NOT NULL;
--ALTER TABLE FRH_RULE_FIRE_FACT 	DROP PRIMARY KEY;
--DROP INDEX PKX_RULE_FIRE_KEY;
--DROP INDEX NDX1_RFF;
--ALTER TABLE FRH_RULE_FIRE_FACT DROP COLUMN CMX_TRAN_ID;
--REORG TABLE FRH_RULE_FIRE_FACT  [KEEPDICTIONARY];
--CREATE INDEX NDX1_RFF  ON FRH_RULE_FIRE_FACT    ( RHX_TRAN_ID ASC, MULTI_ORG_ID ASC, XQO_CUST_NUM ASC, AQO_ACCT_NUM ASC, HQO_CARD_NUM ASC, ALERT_ID ASC, ALERT_VERSION_NBR ASC, RHX_RULE_KEY ASC, RHX_QUEUE_KEY ASC, TRANSACTION_ID ASC, RHX_DATE_KEY ASC, RHX_TIME_KEY ASC, HQO_OB_USERID ASC, HQO_PB_USERID ASC, BUILD_ID ASC, SLOT_ID ASC )  CLUSTER  ALLOW REVERSE SCANS;
--CREATE UNIQUE INDEX PKX_RULE_FIRE_KEY  ON FRH_RULE_FIRE_FACT    ( RHX_TRAN_ID ASC, TRANSACTION_ID ASC, BUILD_ID ASC, SLOT_ID ASC )  ALLOW REVERSE SCANS;
--ALTER TABLE FRH_RULE_FIRE_FACT  ADD CONSTRAINT PKX_RULE_FIRE_KEY PRIMARY KEY    (RHX_TRAN_ID, TRANSACTION_ID, BUILD_ID, SLOT_ID);
--COMMIT;

----------------------------------------------------------
-- OPTION 2: No logging, Generated expression to populate column
----------------------------------------------------------

--UPDATE COMMAND OPTIONS USING c OFF;
--SET INTEGRITY FOR FRH_RULE_FIRE_FACT OFF;
--LOCK TABLE FRH_RULE_FIRE_FACT IN EXCLUSIVE MODE;
--ALTER TABLE FRH_RULE_FIRE_FACT ACTIVATE NOT LOGGED INITIALLY;
--ALTER TABLE FRH_RULE_FIRE_FACT ADD COLUMN RHX_TRAN_ID BIGINT NOT NULL  GENERATED ALWAYS AS (CMX_TRAN_ID);
--SET INTEGRITY FOR FRH_RULE_FIRE_FACT IMMEDIATE CHECKED FORCE GENERATED ;
--ALTER TABLE FRH_RULE_FIRE_FACT ALTER COLUMN RHX_TRAN_ID DROP EXPRESSION;
--ALTER TABLE FRH_RULE_FIRE_FACT DROP PRIMARY KEY;
--DROP INDEX PKX_RULE_FIRE_KEY;
--DROP INDEX NDX1_RFF;
--ALTER TABLE FRH_RULE_FIRE_FACT DROP COLUMN CMX_TRAN_ID;
--REORG TABLE FRH_RULE_FIRE_FACT [KEEPDICTIONARY];;
--CREATE INDEX NDX1_RFF  ON FRH_RULE_FIRE_FACT    ( RHX_TRAN_ID ASC, MULTI_ORG_ID ASC, XQO_CUST_NUM ASC, AQO_ACCT_NUM ASC, HQO_CARD_NUM ASC, ALERT_ID ASC, ALERT_VERSION_NBR ASC, RHX_RULE_KEY ASC, RHX_QUEUE_KEY ASC, TRANSACTION_ID ASC, RHX_DATE_KEY ASC, RHX_TIME_KEY ASC, HQO_OB_USERID ASC, HQO_PB_USERID ASC, BUILD_ID ASC, SLOT_ID ASC )  CLUSTER  ALLOW REVERSE SCANS;
--CREATE UNIQUE INDEX PKX_RULE_FIRE_KEY  ON FRH_RULE_FIRE_FACT    ( RHX_TRAN_ID ASC, TRANSACTION_ID ASC, BUILD_ID ASC, SLOT_ID ASC )  ALLOW REVERSE SCANS;
--ALTER TABLE FRH_RULE_FIRE_FACT  ADD CONSTRAINT PKX_RULE_FIRE_KEY PRIMARY KEY    (RHX_TRAN_ID, TRANSACTION_ID, BUILD_ID, SLOT_ID);
--COMMIT;
